womanIdentifying code for each woman (level 1 unit).
districtIdentifying code for each district (level 2 unit).
useContraceptive use status at time of survey; a factor with levels Not_using and Using.
lcNumber of living children at time of survey; an ordered factor with levels None, One_child, Two_children, Three_plus.
ageAge of woman at time of survey (in years), centred on sample mean of 30 years.
urbanType of region of residence; a factor with levels Rural and Urban.
educWoman's level of education; an ordered factor with levels None, Lower_primary, Upper_primary, Secondary_and_above.
hinduWoman's religion; a factor with levels Muslim and Hindu.
d_illitProportion of women in district who are literate.
d_prayProportion of Muslim women in district who pray every day (a measure of religiosity).
consA column of ones. If included as an explanatory variable in a regression model (e.g. in MLwiN), its coefficient is the intercept.