Learn R Programming

R2MLwiN (version 0.8-2)

gcsemv1: Pupils' marks from GCSE exams (UK, 1989).

Description

GCSE exam results, taken from 73 schools in England, consisting of 1905 pupils.

Arguments

Format

A data frame with 1905 observations on the following variables:
school
School identification (level 2 unit).
student
Student identification (level 1 unit).
female
Gender: a factor with levels Female and Male.
agemths
Age in months.
written
Score on the written component.
csework
Score on the coursework component.
cons
Constant (= 1).

Rasbash, J., Charlton, C., Browne, W.J., Healy, M. and Cameron, B. (2009) MLwiN Version 2.1. Centre for Multilevel Modelling, University of Bristol. Rasbash, J., Steele, F., Browne, W.J. and Goldstein, H. (2012) A User's Guide to MLwiN Version 2.26. Centre for Multilevel Modelling, University of Bristol.

Details

The gcsemv1 dataset is one of the sample datasets provided with the multilevel-modelling software package MLwiN (Rasbash et al., 2009); for further details see Rasbash et al. (2012).

See Also

See mlmRev package for an alternative format of the same dataset, with fewer variables.

Examples

Run this code
## Not run: 
# 
# data(gcsemv1, package = "R2MLwiN")
# 
# (mymodel <- runMLwiN(c(written, csework) ~ 1 + female + (1 | school) + (1 | student), 
#   D = "Multivariate Normal", estoptions = list(EstM = 1), data = gcsemv1))
# 
# ## End(Not run)

Run the code above in your browser using DataLab