Learn R Programming

R2MLwiN (version 0.8-2)

hungary1: Hungarian component of 2nd International Science Survey, '84; see Goldstein 2003

Description

Hungarian component of 2nd International Science Survey, consisting of 2439 women across 99 districts.

Arguments

Format

A data frame with 2439 observations on the following 10 variables:
school
Identifying code for each school (level 2 unit).
female
Gender indicator: a factor with levels Male and Female.
es_core
Core Earth Sciences test result.
biol_core
Core Biology test result.
biol_r3
Optional Biology test result.
biol_r4
Optional Biology test result.
phys_core
Core Physics test result.
phys_r2
Optional Physics test result.
cons
Constant(=1).
student
Identifying code for each student (level 1 unit).

Browne, W. J. (2012) MCMC Estimation in MLwiN Version 2.26. University of Bristol: Centre for Multilevel Modelling. Goldstein, H.. (2003) Multilevel Statistical Models. Third Edition. London, Edward Arnold. Rasbash, J., Charlton, C., Browne, W.J., Healy, M. and Cameron, B. (2009) MLwiN Version 2.1. Centre for Multilevel Modelling, University of Bristol.

Details

The hungary1 dataset is one of the sample datasets provided with the multilevel-modelling software package MLwiN (Rasbash et al., 2009). Originally analysed in Goldstein (2003), further details can also be found in Browne (2012).

Examples

Run this code
## Not run: 
# 
# data(hungary1, package = "R2MLwiN")
# 
# (mymodel <- runMLwiN(c(es_core, biol_core, biol_r3, biol_r4, phys_core, phys_r2) ~ 
#   1 + female + (1 | school) + (1 | student),
#   D = "Multivariate Normal", estoptions = list(EstM = 1), data = hungary1))
# 
# ## End(Not run)

Run the code above in your browser using DataLab