Learn R Programming

R2MLwiN (version 0.8-2)

mlwinfitIGLS-class: An S4 class that stores the outputs of the fitted IGLS model.

Description

An MLwiN model run via the IGLS estimation method is represented by an "mlwinfitIGLS" object

Arguments

Slots

Nobs
Computes the number of complete observations.
DataLength
Total number of cases.
Hierarchy
For each higher level of a multilevel model, returns the number of units at that level, together with the minimum, mean and maximum number of lower-level units nested within units of the current level.
D
A vector specifying the type of distribution to be modelled, which can include 'Normal', 'Binomial' 'Poisson', 'Multinomial', 'Multivariate Normal', or 'Mixed'.
Formula
A formula object (or a character string) specifying a multilevel model.
levID
A character string (vector) of the specified level ID(s).
FP
Displays the fixed part estimates.
RP
Displays the random part estimates.
FP.cov
Displays a covariance matrix of the fixed part estimates.
RP.cov
Displays a covariance matrix of the random part estimates.
elapsed.time
Calculates the CPU time used for fitting the model.
call
The matched call.
LIKE
The deviance statistic (-2*log(like)).
Converged
Boolean indicating whether the model has converged
Iterations
Number of iterations that the model has run for
Meth
If Meth = 0 estimation method is set to RIGLS. If Meth = 1 estimation method is set to IGLS.
residual
If resi.store is TRUE, then the residual estimates at all levels are returned.
data
The data.frame that was used to fit the model.
nonlinear
A character vector specifying linearisation method used. The first element specifies marginal quasi-likelihood linearization (N = 0) or penalised quasi-likelihood linearization (N = 1); The second element specifies first (M = 1) or second (M = 2) order approximation.
version
The MLwiN version used to fit the model

An instance of the Class

An instance is created by calling function runMLwiN.

See Also

runMLwiN

Examples

Run this code
## Not run: 
# library(R2MLwiN)
# # NOTE: if MLwiN not saved in location R2MLwiN defaults to, specify path via:
# # options(MLwiN_path = 'path/to/MLwiN vX.XX/')
# # If using R2MLwiN via WINE, the path may look like this:
# # options(MLwiN_path = '/home/USERNAME/.wine/drive_c/Program Files (x86)/MLwiN vX.XX/')
# 
# ## Example: tutorial
# data(tutorial, package = "R2MLwiN")
# 
# (mymodel <- runMLwiN(normexam ~ 1 + standlrt + (1 + standlrt | school) + (1 | student),
#                      data = tutorial))
# 
# ##summary method
# summary(mymodel)
# 
# ##logLik method
# logLik(mymodel)
# ## End(Not run)

Run the code above in your browser using DataLab