Learn R Programming

R2MLwiN (version 0.8-2)

update,mlwinfitIGLS-method: Update "mlwinfitIGLS" objects

Description

Update "mlwinfitIGLS" objects

Usage

"update"(object, Formula., levID., estoptions., ..., keep.order = TRUE, evaluate = TRUE)

Arguments

object
a valid mlwinfitIGLS class object with an R function call component named call, the expression used to create itself.
Formula.
changes to the formula. This is a two sided formula where "." is substituted for existing components in the Formula component of object$call.
levID.
changes to the specifications of level ID(s).
estoptions.
changes to the specifications of a list of options used for estimating the model.
...
additional arguments to the call, or arguments with changed values.
keep.order
a logical value indicating whether the terms should keep their positions.
evaluate
if TRUE (the default) the new call is evaluated; otherwise the call is returned as an unevaluated expression.

Value

either a new updated mlwinfitIGLS class object, or else an unevaluated expression for creating such an object.