idUnique office worker identifying code.
companyIdentifying code for company worked for over the last 12 months.
company2If worked for >1 company over the last 12 months, identifying code for second company.
company3If worked for >2 companies over the last 12 months, identifying code for third company.
company4If worked for >3 companies over the last 12 months, identifying code for fourth company.
ageAge of worker.
parttimePart or full-time, a factor with levels Fulltime and Parttime.
sexSex of worker, a factor with levels male and female.
consA column of ones. If included as an explanatory variable in a regression model (e.g. in MLwiN), its coefficient is the intercept.
earningsWorkers' earnings over the last financial year.
logearnWorkers' (natural) log-transformed earnings over the last financial year.
numjobsThe number of companies worked for over the last 12 months.
weight1Proportion of time worked for employer listed in company.
weight2Proportion of time worked for employer listed in company2.
weight3Proportion of time worked for employer listed in company3.
weight4Proportion of time worked for employer listed in company4.
ew1Alternative (equal) weighting for company (1/numjobs).
ew2Alternative (equal) weighting for company2 (if numjobs >1 then 1/numjobs, else 0).
ew3Alternative (equal) weighting for company3 (if numjobs >2 then 1/numjobs, else 0).
ew4Alternative (equal) weighting for company4 (if numjobs >3 then 1/numjobs, else 0).
age_40Age of worker, centered on 40 years.